==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/pt_BR.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
    "Storage invalid" : "Armazenamento inválido",
    "Unknown error" : "Erro desconhecido",
    "All files" : "Todos os arquivos",
    "Recent" : "Recentes",
    "Favorites" : "Favoritos",
    "File could not be found" : "O arquivo não foi encontrado",
    "Move or copy" : "Mover ou copiar",
    "Download" : "Baixar",
    "Delete" : "Excluir",
    "Home" : "Início",
    "Close" : "Fechar",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "This will stop your current uploads." : "Isso irá parar seus envios atuais.",
    "Upload cancelled." : "Envio cancelado.",
    "…" : "…",
    "Processing files …" : "Processando arquivos...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não foi possível fazer o envio de {filename}, pois é um diretório ou tem 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não há espaço suficiente, você está enviando {size1} mas resta apenas {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Pasta de destino \"{dir}\" não existe mais",
    "Not enough free space" : "Espaço livre insuficiente",
    "An unknown error has occurred" : "Um erro desconhecido ocorreu",
    "Uploading …" : "Enviando...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "O envio deste item não é suportado",
    "Target folder does not exist any more" : "Pasta destino não existe mais",
    "Error when assembling chunks, status code {status}" : "Erro ao montar partes, código de status {status}",
    "Actions" : "Ações",
    "Rename" : "Renomear",
    "Copy" : "Copiar",
    "Choose target folder" : "Escolher pasta destino",
    "Disconnect storage" : "Desconectar armazenamento",
    "Unshare" : "Descompartilhar",
    "Could not load info for file \"{file}\"" : "Não foi possível carregar informações para o arquivo \"{file}\" ",
    "Files" : "Arquivos",
    "Details" : "Detalhes",
    "Select" : "Selecionar",
    "Pending" : "Pendente",
    "Unable to determine date" : "Impossível determinar a data",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este diretório não está disponível, por favor verifique os logs ou contacte o administrador",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\" pois o destino já existe",
    "Could not move \"{file}\"" : "Não foi possível mover \"{file}\"",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "Não foi possível copiar \"{file}\", pois já existe",
    "Could not copy \"{file}\"" : "Não foi possível copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} foi copiado para {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} e outros {nbfiles} arquivos foram copiados para {destination}",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\" pois ele não existe mais",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está sendo usado na pasta  \"{dir}\". Por favor escolha um nome diferente.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o arquivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o arquivo \"{file}\" pois ele já existe",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\" pois ela já existe",
    "Error deleting file \"{fileName}\"." : "Ocorreu um erro ao excluir o arquivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Sem resultados de pesquisa em outras pastas para {tag}{filter}{endtag}",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas"],
    "_%n file_::_%n files_" : ["%n arquivo","%n arquivos"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluindo %n oculto","incluindo %n ocultos"],
    "You don’t have permission to upload or create files here" : "Você não tem permissão para enviar ou criar arquivos aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["Enviando %n arquivo","Enviando %n arquivos"],
    "New" : "Novo",
    "Select file range" : "Selecionar o intervalo de arquivos",
    "{used} of {quota} used" : "{used} de {quota} usados",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de arquivo inválido.",
    "File name cannot be empty." : "O nome do arquivo não pode estar em branco.",
    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido no nome do arquivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de arquivo permitido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O armazenamento do {owner} está cheio e os arquivos não podem ser mais atualizados ou sincronizados!",
    "Your storage is full, files can not be updated or synced anymore!" : "Seu armazenamento está cheio e arquivos não podem mais ser atualizados ou sincronizados!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O armazenamento do {owner} está quase cheio ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Seu armazenamento está quase cheio ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincide com '{filter}'","coincide com '{filter}'"],
    "View in folder" : "Exibir na pasta",
    "Copied!" : "Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar link direto (somente funciona para usuários que tem acesso a este arquivo/pasta)",
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favoritado",
    "Favorite" : "Favorito",
    "You can only favorite a single file or folder at a time" : "Você só pode favoritar um único arquivo ou pasta de cada vez",
    "New folder" : "Nova pasta",
    "Upload file" : "Enviar arquivo",
    "Not favorited" : "Sem favoritos",
    "Remove from favorites" : "Excluir dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "An error occurred while trying to update the tags" : "Ocorreu um erro enquanto tentava atualizar as etiquetas",
    "Added to favorites" : "Adicionado aos favoritos",
    "Removed from favorites" : "Excluído dos favoritos",
    "You added {file} to your favorites" : "Você adicionou {file} aos seus favoritos",
    "You removed {file} from your favorites" : "Você excluiu {file} dos seus favoritos",
    "File changes" : "Mudanças nos arquivos",
    "Created by {user}" : "Criado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Excluído por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"usuário remoto\"",
    "You created {file}" : "Você criou o arquivo {file}",
    "You created an encrypted file in {file}" : "Você criou um arquivo criptografado em {file}",
    "{user} created {file}" : "{user} criou {file}",
    "{user} created an encrypted file in {file}" : "{user} criou um arquivo criptografado em {file}",
    "{file} was created in a public folder" : "O arquivo {file} foi criado em uma pasta pública",
    "You changed {file}" : "Você modificou o arquivo {file}",
    "You changed an encrypted file in {file}" : "Você alterou um arquivo criptografado em {file}",
    "{user} changed {file}" : "{user} modificou {file}",
    "{user} changed an encrypted file in {file}" : "{user} alterou um arquivo criptografado em {file}",
    "You deleted {file}" : "Você excluiu o arquivo {file}",
    "You deleted an encrypted file in {file}" : "Você excluiu um arquivo criptografado em {file}",
    "{user} deleted {file}" : "{user} excluiu o arquivo {file}",
    "{user} deleted an encrypted file in {file}" : "{user} excluiu um arquivo criptografado em {file}",
    "You restored {file}" : "Você restaurou o arquivo {file}",
    "{user} restored {file}" : "{user} restaurou {file}",
    "You renamed {oldfile} to {newfile}" : "Você renomeou o arquivo {oldfile} para {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} para {newfile}",
    "You moved {oldfile} to {newfile}" : "Você moveu o arquivo {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu o arquivo {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Um arquivo foi adicionado ou excluído de seus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Um arquivo ou pasta foi <strong>alterado</strong> ou <strong>renomeado</strong>",
    "A new file or folder has been <strong>created</strong>" : "Um novo arquivo ou pasta foi <strong>criado</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Um arquivo ou pasta foi <strong>excluído</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Notificações de limite das criações e alterações em seus <strong>arquivos favoritos</strong> <em>(apenas Stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "Um arquivo ou pasta foi <strong>restaurado</strong>",
    "Unlimited" : "Ilimitado",
    "Upload (max. %s)" : "Envio (max. %s)",
    "File Management" : "Gerenciamento de Arquivos",
    "File handling" : "Tratamento de arquivo",
    "Maximum upload size" : "Tamanho máximo para envio",
    "max. possible: " : "max. possível:",
    "Save" : "Salvar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Com PHP-FPM pode demorar 5 minutos para que as alterações sejam aplicadas.",
    "Missing permissions to edit from here." : "Faltando permissões para editar aqui.",
    "%s of %s used" : "%s de %s usado",
    "%1$s%% of %2$s used" : "%1$s%% de %2$s usados",
    "%s used" : "%s usado",
    "Settings" : "Configurações",
    "Show hidden files" : "Mostrar arquivos ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Use este endereço para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">acessar seus arquivos via WebDAV</a>",
    "Toggle grid view" : "Alternar vista de grade",
    "Cancel upload" : "Cancelar envio",
    "No files in here" : "Nenhum arquivo aqui",
    "Upload some content or sync with your devices!" : "Envie um arquivo ou sincronize com seus dispositivos!",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Select all" : "Selecionar tudo",
    "Upload too large" : "Arquivo muito grande para envio",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os arquivos que você está tentando enviar excederam o tamanho máximo para arquivos no servidor.",
    "No favorites yet" : "Você não possui favoritos!",
    "Files and folders you mark as favorite will show up here" : "Suas pastas e arquivos favoritos serão exibidos aqui.",
    "Tags" : "Etiquetas",
    "Deleted files" : "Arquivos excluídos",
    "Shares" : "Compartilhamentos",
    "Shared with others" : "Compartilhado com outros",
    "Shared with you" : "Compartilhado com você",
    "Shared by link" : "Compartilhado via link",
    "Deleted shares" : "Compartilhamentos excluídos",
    "Text file" : "Arquivo texto",
    "New text file.txt" : "Novo texto file.txt",
    "Target folder" : "Pasta destino",
    "%1$s of %2$s used" : "%1$s usado de %2$s"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/pt_BR.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
    "Storage invalid" : "Armazenamento inválido",
    "Unknown error" : "Erro desconhecido",
    "All files" : "Todos os arquivos",
    "Recent" : "Recentes",
    "Favorites" : "Favoritos",
    "File could not be found" : "O arquivo não foi encontrado",
    "Move or copy" : "Mover ou copiar",
    "Download" : "Baixar",
    "Delete" : "Excluir",
    "Home" : "Início",
    "Close" : "Fechar",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "This will stop your current uploads." : "Isso irá parar seus envios atuais.",
    "Upload cancelled." : "Envio cancelado.",
    "Processing files …" : "Processando arquivos...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Não foi possível fazer o envio de {filename}, pois é um diretório ou tem 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não há espaço suficiente, você está enviando {size1} mas resta apenas {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Pasta de destino \"{dir}\" não existe mais",
    "Not enough free space" : "Espaço livre insuficiente",
    "An unknown error has occurred" : "Um erro desconhecido ocorreu",
    "Uploading …" : "Enviando...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "O envio deste item não é suportado",
    "Target folder does not exist any more" : "Pasta destino não existe mais",
    "Error when assembling chunks, status code {status}" : "Erro ao montar partes, código de status {status}",
    "Actions" : "Ações",
    "Rename" : "Renomear",
    "Copy" : "Copiar",
    "Choose target folder" : "Escolher pasta destino",
    "Open" : "Abrir",
    "Delete file" : "Excluir arquivo",
    "Delete folder" : "Excluir pasta",
    "Disconnect storage" : "Desconectar armazenamento",
    "Unshare" : "Descompartilhar",
    "Could not load info for file \"{file}\"" : "Não foi possível carregar informações para o arquivo \"{file}\" ",
    "Files" : "Arquivos",
    "Details" : "Detalhes",
    "Select" : "Selecionar",
    "Pending" : "Pendente",
    "Unable to determine date" : "Impossível determinar a data",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este diretório não está disponível, por favor verifique os logs ou contacte o administrador",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\" pois o destino já existe",
    "Could not move \"{file}\"" : "Não foi possível mover \"{file}\"",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "Não foi possível copiar \"{file}\", pois já existe",
    "Could not copy \"{file}\"" : "Não foi possível copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} foi copiado para {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} e outros {nbfiles} arquivos foram copiados para {destination}",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\" pois ele não existe mais",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está sendo usado na pasta  \"{dir}\". Por favor escolha um nome diferente.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o arquivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o arquivo \"{file}\" pois ele já existe",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\" pois ela já existe",
    "Error deleting file \"{fileName}\"." : "Ocorreu um erro ao excluir o arquivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Sem resultados de pesquisa em outras pastas para {tag}{filter}{endtag}",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas"],
    "_%n file_::_%n files_" : ["%n arquivo","%n arquivos"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluindo %n oculto","incluindo %n ocultos"],
    "You don’t have permission to upload or create files here" : "Você não tem permissão para enviar ou criar arquivos aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["Enviando %n arquivo","Enviando %n arquivos"],
    "New" : "Novo",
    "Select file range" : "Selecionar o intervalo de arquivos",
    "{used} of {quota} used" : "{used} de {quota} usados",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de arquivo inválido.",
    "File name cannot be empty." : "O nome do arquivo não pode estar em branco.",
    "\"/\" is not allowed inside a file name." : "\"/\" não é permitido no nome do arquivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" não é um tipo de arquivo permitido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O armazenamento do {owner} está cheio e os arquivos não podem ser mais atualizados ou sincronizados!",
    "Your storage is full, files can not be updated or synced anymore!" : "Seu armazenamento está cheio e arquivos não podem mais ser atualizados ou sincronizados!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O armazenamento do {owner} está quase cheio ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Seu armazenamento está quase cheio ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincide com '{filter}'","coincide com '{filter}'"],
    "View in folder" : "Exibir na pasta",
    "Copied!" : "Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar link direto (funciona apenas para usuários que tem acesso a este arquivo/pasta)",
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favoritado",
    "Favorite" : "Favorito",
    "You can only favorite a single file or folder at a time" : "Você só pode favoritar um único arquivo ou pasta de cada vez",
    "New folder" : "Nova pasta",
    "Upload file" : "Enviar arquivo",
    "Not favorited" : "Sem favoritos",
    "Remove from favorites" : "Excluir dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "An error occurred while trying to update the tags" : "Ocorreu um erro enquanto tentava atualizar as etiquetas",
    "Added to favorites" : "Adicionado aos favoritos",
    "Removed from favorites" : "Excluído dos favoritos",
    "You added {file} to your favorites" : "Você adicionou {file} aos seus favoritos",
    "You removed {file} from your favorites" : "Você excluiu {file} dos seus favoritos",
    "File changes" : "Mudanças nos arquivos",
    "Created by {user}" : "Criado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Excluído por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"usuário remoto\"",
    "You created {file}" : "Você criou o arquivo {file}",
    "You created an encrypted file in {file}" : "Você criou um arquivo criptografado em {file}",
    "{user} created {file}" : "{user} criou {file}",
    "{user} created an encrypted file in {file}" : "{user} criou um arquivo criptografado em {file}",
    "{file} was created in a public folder" : "O arquivo {file} foi criado em uma pasta pública",
    "You changed {file}" : "Você modificou o arquivo {file}",
    "You changed an encrypted file in {file}" : "Você alterou um arquivo criptografado em {file}",
    "{user} changed {file}" : "{user} modificou {file}",
    "{user} changed an encrypted file in {file}" : "{user} alterou um arquivo criptografado em {file}",
    "You deleted {file}" : "Você excluiu o arquivo {file}",
    "You deleted an encrypted file in {file}" : "Você excluiu um arquivo criptografado em {file}",
    "{user} deleted {file}" : "{user} excluiu o arquivo {file}",
    "{user} deleted an encrypted file in {file}" : "{user} excluiu um arquivo criptografado em {file}",
    "You restored {file}" : "Você restaurou o arquivo {file}",
    "{user} restored {file}" : "{user} restaurou {file}",
    "You renamed {oldfile} to {newfile}" : "Você renomeou o arquivo {oldfile} para {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} para {newfile}",
    "You moved {oldfile} to {newfile}" : "Você moveu o arquivo {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu o arquivo {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Um arquivo foi adicionado ou excluído de seus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Um arquivo ou pasta foi <strong>alterado</strong> ou <strong>renomeado</strong>",
    "A new file or folder has been <strong>created</strong>" : "Um novo arquivo ou pasta foi <strong>criado</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Um arquivo ou pasta foi <strong>excluído</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Notificações de limite das criações e alterações em seus <strong>arquivos favoritos</strong> <em>(apenas Stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "Um arquivo ou pasta foi <strong>restaurado</strong>",
    "Unlimited" : "Ilimitado",
    "Upload (max. %s)" : "Envio (max. %s)",
    "File Management" : "Gerenciamento de Arquivos",
    "Error while loading the file data" : "Erro ao carregar os dados do arquivo",
    "Unable to change the favourite state of the file" : "Não foi possível alterar o estado favorito do arquivo",
    "%s used" : "%s usado",
    "%s%% of %s used" : "%s%% usados de %s",
    "%1$s of %2$s used" : "%1$s usado de %2$s",
    "Settings" : "Configurações",
    "Show hidden files" : "Exibir arquivos ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Use este endereço para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">acessar seus arquivos via WebDAV</a>",
    "Toggle grid view" : "Alternar vista de grade",
    "No files in here" : "Nenhum arquivo aqui",
    "Upload some content or sync with your devices!" : "Envie um arquivo ou sincronize com seus dispositivos!",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Select all" : "Selecionar tudo",
    "Upload too large" : "Arquivo muito grande para envio",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os arquivos que você está tentando enviar excederam o tamanho máximo para arquivos no servidor.",
    "No favorites yet" : "Você não possui favoritos!",
    "Files and folders you mark as favorite will show up here" : "Suas pastas e arquivos favoritos serão exibidos aqui.",
    "Tags" : "Etiquetas",
    "Deleted files" : "Arquivos excluídos",
    "Shares" : "Compartilhamentos",
    "Shared with others" : "Compartilhado com outros",
    "Shared with you" : "Compartilhado com você",
    "Shared by link" : "Compartilhado via link",
    "Deleted shares" : "Compartilhamentos excluídos",
    "Text file" : "Arquivo texto",
    "New text file.txt" : "Novo texto file.txt",
    "File handling" : "Tratamento de arquivo",
    "Maximum upload size" : "Tamanho máximo para envio",
    "max. possible: " : "max. possível:",
    "Save" : "Salvar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Com PHP-FPM pode demorar 5 minutos para que as alterações sejam aplicadas.",
    "Missing permissions to edit from here." : "Faltando permissões para editar aqui.",
    "Cancel upload" : "Cancelar envio",
    "%s of %s used" : "%s de %s usado",
    "%1$s%% of %2$s used" : "%1$s%% de %2$s usados"
},
"nplurals=2; plural=(n > 1);");
